==> jc-1.4.0.tar.gz: soot/tagkit/JasminAttribute.c <==
// public abstract class soot.tagkit.JasminAttribute

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 576421c2c18f78c4 java_util_Hashtable
// @dep_class e283f7c2e7a7979c java_util_Map
// @dep_class 46f178f6d8f2dce8 soot_tagkit_Attribute
// @dep_class 30cb4952e1c8862c soot_tagkit_JasminAttribute
// @dep_class 145f73eb6621ab3a soot_tagkit_Tag

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_util_Hashtable
// @dep_header java_util_Map
// @dep_header soot_tagkit_Attribute
// @dep_header soot_tagkit_JasminAttribute
// @dep_header soot_tagkit_Tag

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/util/Hashtable.h"
#include "java/util/Map.h"
#include "soot/tagkit/Attribute.h"
#include "soot/tagkit/JasminAttribute.h"
#include "soot/tagkit/Tag.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_soot_tagkit_JasminAttribute$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_soot_tagkit_JasminAttribute$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_soot_tagkit_JasminAttribute$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_soot_tagkit_JasminAttribute$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_tagkit_JasminAttribute$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_tagkit_JasminAttribute$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_tagkit_JasminAttribute$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_tagkit_JasminAttribute, _init$52f4ad9f2989aeee);

void
_jc_soot_tagkit_JasminAttribute$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_soot_tagkit_JasminAttribute$object *this)
{
	struct _jc_soot_tagkit_JasminAttribute$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(64);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public abstract byte[] decode(java.lang.String, java.util.Hashtable)
//

static const unsigned char _jc_soot_tagkit_JasminAttribute$param_ptypes$decode$842483d88e34cc59[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_soot_tagkit_JasminAttribute$param_types$decode$842483d88e34cc59[] = {
	&_jc_java_lang_String$type,
	&_jc_java_util_Hashtable$type
};

_jc_method _jc_soot_tagkit_JasminAttribute$method_info$decode$842483d88e34cc59 = {
	.name=			"decode",
	.signature=		"(Ljava/lang/String;Ljava/util/Hashtable;)[B",
	.class=			&_jc_soot_tagkit_JasminAttribute$type,
	.param_types=		&_jc_soot_tagkit_JasminAttribute$param_types$decode$842483d88e34cc59,
	.return_type=		&_jc_byte$array$prim$type,
	.param_ptypes=		&_jc_soot_tagkit_JasminAttribute$param_ptypes$decode$842483d88e34cc59,
	.signature_hash=	_JC_JLONG(0x842483d88e34cc59),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.function=		&_jc_soot_tagkit_JasminAttribute$method$decode$842483d88e34cc59,
	.vtable_index=		_JC_OFFSETOF(struct _jc_soot_tagkit_JasminAttribute$vtable, soot_tagkit_JasminAttribute.decode$842483d88e34cc59) / sizeof(void *),
	.num_parameters=	2,
};

_jc_byte_array *
_jc_soot_tagkit_JasminAttribute$method$decode$842483d88e34cc59(_jc_env *const env, _jc_soot_tagkit_JasminAttribute$object *this, _jc_java_lang_String$object *param0, _jc_java_util_Hashtable$object *param1)
{
	_JC_ABSTRACT_METHOD(env, &_jc_soot_tagkit_JasminAttribute$method_info$decode$842483d88e34cc59);
}

//
// public abstract java.lang.String getJasminValue(java.util.Map)
//

static const unsigned char _jc_soot_tagkit_JasminAttribute$param_ptypes$getJasminValue$3e470c5e1d385827[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_soot_tagkit_JasminAttribute$param_types$getJasminValue$3e470c5e1d385827[] = {
	&_jc_java_util_Map$type
};

_jc_method _jc_soot_tagkit_JasminAttribute$method_info$getJasminValue$3e470c5e1d385827 = {
	.name=			"getJasminValue",
	.signature=		"(Ljava/util/Map;)Ljava/lang/String;",
	.class=			&_jc_soot_tagkit_JasminAttribute$type,
	.param_types=		&_jc_soot_tagkit_JasminAttribute$param_types$getJasminValue$3e470c5e1d385827,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_soot_tagkit_JasminAttribute$param_ptypes$getJasminValue$3e470c5e1d385827,
	.signature_hash=	_JC_JLONG(0x3e470c5e1d385827),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.function=		&_jc_soot_tagkit_JasminAttribute$method$getJasminValue$3e470c5e1d385827,
	.vtable_index=		_JC_OFFSETOF(struct _jc_soot_tagkit_JasminAttribute$vtable, soot_tagkit_JasminAttribute.getJasminValue$3e470c5e1d385827) / sizeof(void *),
	.num_parameters=	1,
};

_jc_java_lang_String$object *
_jc_soot_tagkit_JasminAttribute$method$getJasminValue$3e470c5e1d385827(_jc_env *const env, _jc_soot_tagkit_JasminAttribute$object *this, _jc_object *param0)
{
	_JC_ABSTRACT_METHOD(env, &_jc_soot_tagkit_JasminAttribute$method_info$getJasminValue$3e470c5e1d385827);
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_soot_tagkit_JasminAttribute$methods[] = {
	&_jc_soot_tagkit_JasminAttribute$method_info$_init$52f4ad9f2989aeee,
	&_jc_soot_tagkit_JasminAttribute$method_info$decode$842483d88e34cc59,
	&_jc_soot_tagkit_JasminAttribute$method_info$getJasminValue$3e470c5e1d385827
};

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_soot_tagkit_JasminAttribute$interfaces[] = {
	&_jc_soot_tagkit_Attribute$type
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_soot_tagkit_JasminAttribute$instanceof_hash_bucket_44[] = {
	&_jc_soot_tagkit_JasminAttribute$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_tagkit_JasminAttribute$instanceof_hash_bucket_58[] = {
	&_jc_soot_tagkit_Tag$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_tagkit_JasminAttribute$instanceof_hash_bucket_104[] = {
	&_jc_soot_tagkit_Attribute$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_tagkit_JasminAttribute$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_soot_tagkit_JasminAttribute$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[44]=	_jc_soot_tagkit_JasminAttribute$instanceof_hash_bucket_44,
	[58]=	_jc_soot_tagkit_JasminAttribute$instanceof_hash_bucket_58,
	[104]=	_jc_soot_tagkit_JasminAttribute$instanceof_hash_bucket_104,
	[113]=	_jc_soot_tagkit_JasminAttribute$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_soot_tagkit_JasminAttribute$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "java/util/Hashtable",	_JC_JLONG(0x576421c2c18f78c4) },
	{ "java/util/Map",	_JC_JLONG(0xe283f7c2e7a7979c) },
	{ "soot/tagkit/Attribute",	_JC_JLONG(0x46f178f6d8f2dce8) },
	{ "soot/tagkit/Tag",	_JC_JLONG(0x145f73eb6621ab3a) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_soot_tagkit_JasminAttribute$vtype _jc_soot_tagkit_JasminAttribute$type = {
    .type= {
	.name=			"soot/tagkit/JasminAttribute",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_soot_tagkit_JasminAttribute$interfaces) / sizeof(*_jc_soot_tagkit_JasminAttribute$interfaces),
	.interfaces=		_jc_soot_tagkit_JasminAttribute$interfaces,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0x30cb4952e1c8862c),
		.source_file=		"JasminAttribute.java",
		.instance_size=		sizeof(_jc_soot_tagkit_JasminAttribute$refs) + sizeof(_jc_soot_tagkit_JasminAttribute$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_soot_tagkit_JasminAttribute$methods) / sizeof(*_jc_soot_tagkit_JasminAttribute$methods),
		.methods=		_jc_soot_tagkit_JasminAttribute$methods,
		.instanceof_hash_table=	_jc_soot_tagkit_JasminAttribute$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_soot_tagkit_JasminAttribute$class_depends) / sizeof(*_jc_soot_tagkit_JasminAttribute$class_depends),
		.class_depends=		_jc_soot_tagkit_JasminAttribute$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.soot_tagkit_JasminAttribute= {
	    .decode$842483d88e34cc59=
		&_jc_soot_tagkit_JasminAttribute$method$decode$842483d88e34cc59,
	    .getJasminValue$3e470c5e1d385827=
		&_jc_soot_tagkit_JasminAttribute$method$getJasminValue$3e470c5e1d385827,
	},
    }
};

==> jc-1.4.5.tar.gz: soot/tagkit/JasminAttribute.c <==
// public abstract class soot.tagkit.JasminAttribute

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 576421c2c18f78c4 java_util_Hashtable
// @dep_class e283f7c2e7a7979c java_util_Map
// @dep_class 46f178f6d8f2dce8 soot_tagkit_Attribute
// @dep_class 30cb4952e1c8862c soot_tagkit_JasminAttribute
// @dep_class 145f73eb6621ab3a soot_tagkit_Tag

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_util_Hashtable
// @dep_header java_util_Map
// @dep_header soot_tagkit_Attribute
// @dep_header soot_tagkit_JasminAttribute
// @dep_header soot_tagkit_Tag

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/util/Hashtable.h"
#include "java/util/Map.h"
#include "soot/tagkit/Attribute.h"
#include "soot/tagkit/JasminAttribute.h"
#include "soot/tagkit/Tag.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_soot_tagkit_JasminAttribute$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_soot_tagkit_JasminAttribute$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_soot_tagkit_JasminAttribute$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_soot_tagkit_JasminAttribute$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_tagkit_JasminAttribute$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_tagkit_JasminAttribute$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_tagkit_JasminAttribute$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_tagkit_JasminAttribute, _init$52f4ad9f2989aeee);

void _JC_JCNI_ATTR
_jc_soot_tagkit_JasminAttribute$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_soot_tagkit_JasminAttribute$object *this)
{
	struct _jc_soot_tagkit_JasminAttribute$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(64);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public abstract byte[] decode(java.lang.String, java.util.Hashtable)
//

static const unsigned char _jc_soot_tagkit_JasminAttribute$param_ptypes$decode$842483d88e34cc59[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_soot_tagkit_JasminAttribute$param_types$decode$842483d88e34cc59[] = {
	&_jc_java_lang_String$type,
	&_jc_java_util_Hashtable$type
};

_jc_method _jc_soot_tagkit_JasminAttribute$method_info$decode$842483d88e34cc59 = {
	.name=			"decode",
	.signature=		"(Ljava/lang/String;Ljava/util/Hashtable;)[B",
	.class=			&_jc_soot_tagkit_JasminAttribute$type,
	.param_types=		&_jc_soot_tagkit_JasminAttribute$param_types$decode$842483d88e34cc59,
	.return_type=		&_jc_byte$array$prim$type,
	.param_ptypes=		&_jc_soot_tagkit_JasminAttribute$param_ptypes$decode$842483d88e34cc59,
	.signature_hash=	_JC_JLONG(0x842483d88e34cc59),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.function=		&_jc_soot_tagkit_JasminAttribute$method$decode$842483d88e34cc59,
	.vtable_index=		_JC_OFFSETOF(struct _jc_soot_tagkit_JasminAttribute$vtable, soot_tagkit_JasminAttribute.decode$842483d88e34cc59) / sizeof(void *),
	.num_parameters=	2,
};

_jc_byte_array * _JC_JCNI_ATTR
_jc_soot_tagkit_JasminAttribute$method$decode$842483d88e34cc59(_jc_env *const env, _jc_soot_tagkit_JasminAttribute$object *this, _jc_java_lang_String$object *param0, _jc_java_util_Hashtable$object *param1)
{
	_JC_ABSTRACT_METHOD(env, &_jc_soot_tagkit_JasminAttribute$method_info$decode$842483d88e34cc59);
}

//
// public abstract java.lang.String getJasminValue(java.util.Map)
//

static const unsigned char _jc_soot_tagkit_JasminAttribute$param_ptypes$getJasminValue$3e470c5e1d385827[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_soot_tagkit_JasminAttribute$param_types$getJasminValue$3e470c5e1d385827[] = {
	&_jc_java_util_Map$type
};

_jc_method _jc_soot_tagkit_JasminAttribute$method_info$getJasminValue$3e470c5e1d385827 = {
	.name=			"getJasminValue",
	.signature=		"(Ljava/util/Map;)Ljava/lang/String;",
	.class=			&_jc_soot_tagkit_JasminAttribute$type,
	.param_types=		&_jc_soot_tagkit_JasminAttribute$param_types$getJasminValue$3e470c5e1d385827,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_soot_tagkit_JasminAttribute$param_ptypes$getJasminValue$3e470c5e1d385827,
	.signature_hash=	_JC_JLONG(0x3e470c5e1d385827),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.function=		&_jc_soot_tagkit_JasminAttribute$method$getJasminValue$3e470c5e1d385827,
	.vtable_index=		_JC_OFFSETOF(struct _jc_soot_tagkit_JasminAttribute$vtable, soot_tagkit_JasminAttribute.getJasminValue$3e470c5e1d385827) / sizeof(void *),
	.num_parameters=	1,
};

_jc_java_lang_String$object * _JC_JCNI_ATTR
_jc_soot_tagkit_JasminAttribute$method$getJasminValue$3e470c5e1d385827(_jc_env *const env, _jc_soot_tagkit_JasminAttribute$object *this, _jc_object *param0)
{
	_JC_ABSTRACT_METHOD(env, &_jc_soot_tagkit_JasminAttribute$method_info$getJasminValue$3e470c5e1d385827);
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_soot_tagkit_JasminAttribute$methods[] = {
	&_jc_soot_tagkit_JasminAttribute$method_info$_init$52f4ad9f2989aeee,
	&_jc_soot_tagkit_JasminAttribute$method_info$decode$842483d88e34cc59,
	&_jc_soot_tagkit_JasminAttribute$method_info$getJasminValue$3e470c5e1d385827
};

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_soot_tagkit_JasminAttribute$interfaces[] = {
	&_jc_soot_tagkit_Attribute$type
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_soot_tagkit_JasminAttribute$instanceof_hash_bucket_44[] = {
	&_jc_soot_tagkit_JasminAttribute$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_tagkit_JasminAttribute$instanceof_hash_bucket_58[] = {
	&_jc_soot_tagkit_Tag$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_tagkit_JasminAttribute$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_tagkit_JasminAttribute$instanceof_hash_bucket_104[] = {
	&_jc_soot_tagkit_Attribute$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_soot_tagkit_JasminAttribute$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[44]=	_jc_soot_tagkit_JasminAttribute$instanceof_hash_bucket_44,
	[58]=	_jc_soot_tagkit_JasminAttribute$instanceof_hash_bucket_58,
	[101]=	_jc_soot_tagkit_JasminAttribute$instanceof_hash_bucket_101,
	[104]=	_jc_soot_tagkit_JasminAttribute$instanceof_hash_bucket_104
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_soot_tagkit_JasminAttribute$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "java/util/Hashtable",	_JC_JLONG(0x576421c2c18f78c4) },
	{ "java/util/Map",	_JC_JLONG(0xe283f7c2e7a7979c) },
	{ "soot/tagkit/Attribute",	_JC_JLONG(0x46f178f6d8f2dce8) },
	{ "soot/tagkit/Tag",	_JC_JLONG(0x145f73eb6621ab3a) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_soot_tagkit_JasminAttribute$vtype _jc_soot_tagkit_JasminAttribute$type = {
    .type= {
	.name=			"soot/tagkit/JasminAttribute",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_soot_tagkit_JasminAttribute$interfaces) / sizeof(*_jc_soot_tagkit_JasminAttribute$interfaces),
	.interfaces=		_jc_soot_tagkit_JasminAttribute$interfaces,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0x30cb4952e1c8862c),
		.source_file=		"JasminAttribute.java",
		.instance_size=		sizeof(_jc_soot_tagkit_JasminAttribute$refs) + sizeof(_jc_soot_tagkit_JasminAttribute$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_soot_tagkit_JasminAttribute$methods) / sizeof(*_jc_soot_tagkit_JasminAttribute$methods),
		.methods=		_jc_soot_tagkit_JasminAttribute$methods,
		.instanceof_hash_table=	_jc_soot_tagkit_JasminAttribute$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_soot_tagkit_JasminAttribute$class_depends) / sizeof(*_jc_soot_tagkit_JasminAttribute$class_depends),
		.class_depends=		_jc_soot_tagkit_JasminAttribute$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.soot_tagkit_JasminAttribute= {
	    .decode$842483d88e34cc59=
		&_jc_soot_tagkit_JasminAttribute$method$decode$842483d88e34cc59,
	    .getJasminValue$3e470c5e1d385827=
		&_jc_soot_tagkit_JasminAttribute$method$getJasminValue$3e470c5e1d385827,
	},
    }
};
